## Pull requests are always welcome! 

Please follow a few guidelines:

- Please don't include updated versions of `rickshaw.js` and `rickshaw.min.js`. Just changes to the source files will suffice.
- Add a unit test or two to cover the proposed changes
- Please run the tests and make sure tests are all passing before submitting your pull request
- Do as the Romans do and stick with existing whitespace and formatting conventions (i.e., tabs instead of spaces, etc)
- Consider adding a simple example under examples/ that demonstrates any new functionality
